// *************************************************************************
// xorg-edit
// Copyright 2006, 2007 Dominik Wagenfuehr <dominik.wagenfuehr@deesaster.org>
// Licence: GPLv3
// *************************************************************************

/**
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef OPTIONDIALOG_H
#define OPTIONDIALOG_H

// **************************************
// Header Files
// **************************************

#include <wx/wx.h>
#include <wx/dialog.h>
#include <wx/textctrl.h>
#include <wx/string.h>
#include <wx/notebook.h>

#include "../libxorgedit/device.h"
#include "../libxorgedit/inputdevice.h"
#include "../libxorgedit/driveroptionlist.h"
#include "../libxorgedit/optionlist.h"

// **************************
// Class Definition
// **************************

class OptionDialog: public wxDialog
{
public:
  OptionDialog(const wxString& title, const DriverOptionList& list, Device& device);
  OptionDialog(const wxString& title, const DriverOptionList& list, InputDevice& device);
  OptionDialog(const wxString& title, OptionList& options);
  virtual ~OptionDialog();

  void OnTabChange(wxNotebookEvent& event);     // some tab has changed

  // buttons
  void OnOK(wxCommandEvent& event);
  void OnCancel(wxCommandEvent& event);

private:
  const bool AcceptDevice(bool& changed);         // accept all changes in device
  const bool AcceptInputDevice(bool& changed);  // accept all changes in input device
  const bool AcceptOptions(bool& changed);       // accept all changes in options

  Device *dPointer;                  // pointer to device
  InputDevice *idPointer;          // pointer to input device
  OptionList *oPointer;           // pointer to options
  wxTextCtrl *optionDesc;

  DriverOptionList generalList;    // list for each tab that will be changed in OptionWindow
  DriverOptionList advancedList;
  DriverOptionList dualList;

  DECLARE_EVENT_TABLE();

  // IDs for the controls and the menu commands
  enum OptionDialogID
  {
    CHANGE_TAB=1000,
  };

};

#endif // OPTIONDIALOG_H


